prepend

Function prepend 

unsafe fn prepend<T, A: Allocator>(deque: &mut VecDeque<T, A>, slice: &[T])
Prepends elements of slice to deque using a copy.

Safety

  • deque must have space for slice.len() new elements.
  • Elements of slice will be copied into the deque, make sure to forget the elements if T is not Copy.