unsafe fn prepend<T, A: Allocator>(deque: &mut VecDeque<T, A>, slice: &[T])Expand description
Prepends elements of slice to deque using a copy.
Safety
dequemust have space forslice.len()new elements.- Elements of
slicewill be copied into the deque, make sure to forget the elements ifTis notCopy.